import 'package:domain/entity/user_me_entity.dart';
import 'package:plugin_platform/platform_export.dart';
import 'package:plugin_platform/http/dio_engine.dart';
import 'package:plugin_platform/http/http_result.dart';
import 'package:riverpod_annotation/riverpod_annotation.dart';
import 'package:shared/utils/util.dart';
import '../constants/api_constants.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:plugin_basic/provider/http_provider/http_provider.dart';

part 'profile_repository.g.dart';

@Riverpod(keepAlive: true)
ProfileRepository profileRepository(Ref ref) {
  final dioEngine = ref.watch(dioEngineProvider);
  return ProfileRepository(dioEngine: dioEngine);
}

/*
 * 用户详情的数据仓库
 */
class ProfileRepository {
  DioEngine dioEngine;

  ProfileRepository({required this.dioEngine});

  /// 获取用户详情
  Future<HttpResult<UserMeEntity>> fetchUserInfo({
    CancelToken? cancelToken,
  }) async {
    final result = await dioEngine.requestNetResult(
      ApiConstants.apiProfileInfo,
      method: HttpMethod.GET,
      cancelToken: cancelToken,
    );

    if (result.isSuccess) {
      final json = result.getDataJson();
      var data = UserMeEntity.fromJson(json!);
      return result.convert<UserMeEntity>(data: data);
    }
    return result.convert();
  }

  /// 更新用户信息
  Future<HttpResult> updateProfile({
    required String? firstName,
    required String? lastName,
    required String? email,
    required String? avatarPath,
    CancelToken? cancelToken,
  }) async {
    Map<String, String> params = {};
    params['first_name'] = firstName!;
    params['last_name'] = lastName!;
    params['email'] = email!;

    Map<String, String> paths = {};

    //如果是链接通过params传参
    if (avatarPath != null && avatarPath.startsWith("http")) {
      params['avatar'] = avatarPath;
    } else {
      //如果是文件通过Path传参
      paths['avatar'] = avatarPath ?? "";
    }

    final result = await dioEngine.requestNetResult(
      ApiConstants.apiUpdateProfile,
      params: params,
      paths: paths,
      method: HttpMethod.POST,
      isShowLoadingDialog: true,
      networkDebounce: true,
      cancelToken: cancelToken,
    );

    if (result.isSuccess) {
      return result.convert();
    }
    return result.convert();
  }
}
